# pyinvc
Baloot billing module

# Contributing to the Project

## Commit Messages

We follow the [Conventional Commits](https://www.conventionalcommits.org/en/v1.0.0/). The commit message should be structured as follows:

```
<type>[optional scope]: <description>

[optional body]

[optional footer(s)]
```

Here's a list of `types` you can use for your commit message:

- **feat**: A new feature
- **fix**: A bug fix
- **docs**: Documentation changes
- **style**: Code style changes (like formatting)
- **refactor**: Code changes that neither fix a bug nor add a feature
- **test**: Adding or modifying tests
- **chore**: Routine tasks, such as dependencies updates

Commit message example:
```
feat(auth): add login API endpoint
feat(lang): add Polish language
```